@@ -4,6 +4,8 @@ NODE=$(hostname -s)
 
 TYPE="$2"
 
+BRANCH="$6"
+
 echo "kolla_base_distro: $1" >> kolla-ansible/etc/kolla/globals.yml
 cat tests/conf/iscsi-all-in-one/kolla_config >> kolla-ansible/etc/kolla/globals.yml
 IP=172.18.0.1
@@ -19,6 +21,7 @@ kolla-ansible/tools/generate_passwords.py
 kolla-ansible/tools/kolla-ansible genconfig
 
 crudini --set /etc/kolla/nova-compute/nova.conf libvirt virt_type qemu
+crudini --set /etc/kolla/nova-compute/nova.conf libvirt cpu_mode none
 
 # Keystone does not seem to invalidate its cache on entry point addition.
 crudini --set /etc/kolla/keystone/keystone.conf cache enabled False
